==> aioqui-2.0.6.tar.gz: aioqui-2.0.6/src/aioqui/widgets/extensions/layout_ext.py <==
from PySide6.QtWidgets import QWidget, QLayoutItem, QSpacerItem
from PySide6.QtCore import Qt, QObject
from typing import Sequence, Iterable

from ...types import Alignment


class LayoutExt(Alignment):
    async def init(
            self, *,
            margins: tuple[int, ...] = (0, 0, 0, 0), spacing: int = 0, alignment: Qt.Alignment = None,
            items: Sequence[QObject] = ()
    ) -> 'LayoutExt':
        self.setContentsMargins(*margins)
        self.setSpacing(spacing)
        if alignment:
            self.setAlignment(alignment)
        self.add_items(items)
        return self

    def add(self, obj: QObject, alignment: Qt.AlignmentFlag = None) -> QObject:
        if isinstance(obj, QWidget):
            if alignment:
                self.addWidget(obj, alignment=alignment)
            else:
                self.addWidget(obj)
        elif isinstance(obj, QSpacerItem):
            self.addSpacerItem(obj)
        elif isinstance(obj, QLayoutItem):
            self.addLayout(obj)
        else:
            raise TypeError(f'{obj} has unsupported type {type(obj)} to `add` to {self}')
        return obj

    def add_items(self, items: Sequence[QObject]):
        i = 0
        while i < len(items):
            if i + 1 < len(items) and isinstance(items[i + 1], (Qt.AlignmentFlag, Qt.Alignment)):
                self.add(items[i], items[i + 1])
                i += 1
            else:
                self.add(items[i])
            i += 1

    def clear(self, exceptions: Iterable[QObject] = ()):
        for i in reversed(range(self.count())):
            layout_item = self.itemAt(i).widget()
            if not layout_item:
                layout_item = self.itemAt(i).layout()
            if not layout_item:
                layout_item = self.itemAt(i).spacerItem()
            if layout_item not in exceptions:
                layout_item.setParent(None)

==> aioqui-2.1.0.tar.gz: aioqui-2.1.0/src/aioqui/widgets/extensions/layout_ext.py <==
from PySide6.QtWidgets import QWidget, QLayoutItem, QSpacerItem
from PySide6.QtCore import Qt, QObject
from typing import Sequence, Iterable

from ...types import Alignment


class LayoutExt(Alignment):
    async def init(
            self, *,
            items: Sequence[QObject] = (),
            **kwargs
    ) -> 'LayoutExt':
        i = 0
        while i < len(items):
            if i + 1 < len(items) and isinstance(items[i + 1], (Qt.AlignmentFlag, Qt.Alignment)):
                self.add(items[i], items[i + 1])
                i += 1
            else:
                self.add(items[i])
            i += 1
        return await self._render(**kwargs)  # from ContextObj

    def add(self, obj: QObject, alignment: Alignment.Alignment = None) -> QObject:
        if isinstance(obj, QWidget):
            if alignment:
                self.addWidget(obj, alignment=alignment)
            else:
                self.addWidget(obj)
        elif isinstance(obj, QSpacerItem):
            self.addSpacerItem(obj)
        elif isinstance(obj, QLayoutItem):
            self.addLayout(obj)
        else:
            raise TypeError(f'{obj} has unsupported type {type(obj)} to `add` to {self}')
        return obj

    def reorder(self, at: int, to: int):
        self.removeItem(item := self.itemAt(at))
        self.insertItem(to, item)

    def clear(self, exceptions: Iterable[QObject] = ()):
        for i in reversed(range(self.count())):
            item = self.itemAt(i).widget()
            if not item:
                item = self.itemAt(i).layout()
            if not item:
                item = self.itemAt(i).spacerItem()
            if item not in exceptions:
                item.setParent(None)
